==> TundereBird-0.24.tar.bz2: TundereBird-0.24/core/Smdn.Net.Imap4.Client/Smdn.Net.Imap4.Client.Transaction.BuiltIn/EnableTransaction.cs <==
// 
// Author:
//       smdn <smdn@mail.invisiblefulmoon.net>
// 
// Copyright (c) 2008-2010 smdn
// 
// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files (the "Software"), to deal
// in the Software without restriction, including without limitation the rights
// to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
// copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions:
// 
// The above copyright notice and this permission notice shall be included in
// all copies or substantial portions of the Software.
// 
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
// THE SOFTWARE.

using System;

using Smdn.Net.Imap4.Protocol;
using Smdn.Net.Imap4.Protocol.Client;

namespace Smdn.Net.Imap4.Client.Transaction.BuiltIn {
  internal class EnableTransaction : ImapTransactionBase<ImapTransactionResult<ImapCapabilityList>>, IImapExtension {
    ImapCapability IImapExtension.RequiredCapability {
      get { return ImapCapability.Enable; }
    }

    public EnableTransaction(ImapConnection connection)
      : base(connection)
    {
    }

    protected override ProcessTransactionDelegate Reset()
    {
      if (!Request.Arguments.ContainsKey("capability names"))
        return ProcessArgumentNotSetted;
      else
        return ProcessEnable;
    }

    private void ProcessArgumentNotSetted()
    {
      FinishError(ImapTransactionResultCode.RequestError, "arguments 'capability names' must be setted");
    }

    // 3.1. The ENABLE Command
    //    Arguments: capability names
    //    Result:    OK: Relevant capabilities enabled
    //               BAD: No arguments, or syntax error in an argument
    private void ProcessEnable()
    {
      // ENABLE
      SendCommand("ENABLE", ProcessReceiveResponse, Request.Arguments["capability names"]);
    }

    protected override void OnDataResponseReceived(ImapDataResponse data)
    {
      if (data.Type == ImapDataResponseType.Enabled)
        enabledCapabilities = ImapDataResponseConverter.FromEnabled(data);

      base.OnDataResponseReceived(data);
    }

    protected override void OnTaggedStatusResponseReceived(ImapTaggedStatusResponse tagged)
    {
      if (tagged.Condition == ImapResponseCondition.Ok)
        Finish(new ImapTransactionResult<ImapCapabilityList>(enabledCapabilities, tagged.ResponseText.Text));
      else
        base.OnTaggedStatusResponseReceived(tagged);
    }

    private ImapCapabilityList enabledCapabilities = null;
  }
}

==> TundereBird-0.28.tar.bz2: TundereBird-0.28/core/Smdn.Net.Imap4.Client/Smdn.Net.Imap4.Client.Transaction.BuiltIn/EnableTransaction.cs <==
// 
// Author:
//       smdn <smdn@mail.invisiblefulmoon.net>
// 
// Copyright (c) 2008-2010 smdn
// 
// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files (the "Software"), to deal
// in the Software without restriction, including without limitation the rights
// to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
// copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions:
// 
// The above copyright notice and this permission notice shall be included in
// all copies or substantial portions of the Software.
// 
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
// THE SOFTWARE.

using System;

using Smdn.Net.Imap4.Protocol;
using Smdn.Net.Imap4.Protocol.Client;

namespace Smdn.Net.Imap4.Client.Transaction.BuiltIn {
  internal class EnableTransaction : ImapTransactionBase<ImapTransactionResult<ImapCapabilityList>>, IImapExtension {
    ImapCapability IImapExtension.RequiredCapability {
      get { return ImapCapability.Enable; }
    }

    public EnableTransaction(ImapConnection connection)
      : base(connection)
    {
    }

    protected override ProcessTransactionDelegate Reset()
    {
      if (!Request.Arguments.ContainsKey("capability names"))
        return ProcessArgumentNotSetted;
      else
        return ProcessEnable;
    }

    private void ProcessArgumentNotSetted()
    {
      FinishError(ImapTransactionResultCode.RequestError, "arguments 'capability names' must be setted");
    }

    // 3.1. The ENABLE Command
    //    Arguments: capability names
    //    Result:    OK: Relevant capabilities enabled
    //               BAD: No arguments, or syntax error in an argument
    private void ProcessEnable()
    {
      // ENABLE
      SendCommand("ENABLE", ProcessReceiveResponse, Request.Arguments["capability names"]);
    }

    protected override void OnDataResponseReceived(ImapDataResponse data)
    {
      if (data.Type == ImapDataResponseType.Enabled)
        enabledCapabilities = ImapDataResponseConverter.FromEnabled(data);

      base.OnDataResponseReceived(data);
    }

    protected override void OnTaggedStatusResponseReceived(ImapTaggedStatusResponse tagged)
    {
      if (tagged.Condition == ImapResponseCondition.Ok)
        Finish(new ImapTransactionResult<ImapCapabilityList>(enabledCapabilities, tagged.ResponseText));
      else
        base.OnTaggedStatusResponseReceived(tagged);
    }

    private ImapCapabilityList enabledCapabilities = null;
  }
}
